@@ -2,7 +2,7 @@ import os
 import shutil
 import argparse
 
-__version__ = '1.0.5'
+__version__ = '1.0.7'
 
 
 def parse_args():
@@ -46,9 +46,10 @@ def format_dir(root, project_name):
 def main():
     args = parse_args()
     if args.cmd == 'create':
-        print(f'Will create Flask project with name "{args.name}"')
+        project_name = args.name
+        print(f'Will create Flask project with name "{project_name}"')
         dir_name = os.path.dirname(__file__)
-        source_dir = os.path.join(dir_name, 'templates', 'project_template', {args.name})
+        source_dir = os.path.join(dir_name, 'templates', 'project_template', 'project_name')
         dist_dir = os.path.join(os.getcwd(), args.name)
         if dist_dir_check(dist_dir, ):
             shutil.copytree(source_dir, dist_dir,
